@@ -31,7 +31,7 @@ ruma_api! {
     response: {
         /// For each key algorithm, the number of unclaimed one-time keys of that
         /// type currently held on the server for this device.
-        pub one_time_key_counts: BTreeMap<DeviceKeyAlgorithm, UInt>
+        pub one_time_key_counts: BTreeMap<DeviceKeyAlgorithm, UInt>,
     }
 
     error: crate::Error
