@@ -30,7 +30,17 @@ ruma_api! {
             feature = "compat",
             serde(default, deserialize_with = "ruma_serde::empty_string_as_none")
         )]
-        pub avatar_url: Option<MxcUri>
+        pub avatar_url: Option<MxcUri>,
+
+        /// The [BlurHash](https://blurha.sh) for the avatar pointed to by `avatar_url`.
+        ///
+        /// This uses the unstable prefix in
+        /// [MSC2448](https://github.com/matrix-org/matrix-doc/pull/2448).
+        #[cfg(feature = "unstable-pre-spec")]
+        #[cfg_attr(docsrs, doc(cfg(feature = "unstable-pre-spec")))]
+        #[serde(rename = "xyz.amorgan.blurhash")]
+        #[serde(skip_serializing_if = "Option::is_none")]
+        pub blurhash: Option<String>,
     }
 
     error: crate::Error
@@ -46,6 +56,10 @@ impl<'a> Request<'a> {
 impl Response {
     /// Creates a new `Response` with the given avatar URL.
     pub fn new(avatar_url: Option<MxcUri>) -> Self {
-        Self { avatar_url }
+        Self {
+            avatar_url,
+            #[cfg(feature = "unstable-pre-spec")]
+            blurhash: None,
+        }
     }
 }
